##################################################################################################
#                                                                                                #
##PROJECT:      DFG 2-Phase / Promotion      											                               #
#                                                                                                #
##PROGRAM NAME: 5_graphs.sas     	                                                               #
#                                                                                                #
##AUTHOR:       D. Enders					                                     	                         #
#                                                                                                #
##VERSION/DATE: V 1.0 / 22nd Dec 2017   				 								                                 #
#                                                                                                #
##PURPOSE:      Produces tables and graphs for publication                                       #
#                                                                                                #
##Read: path - folder containing results of 3_sim_ana1.R and 4_sim_ana2.R                        #  
##################################################################################################

#########################
#Options  and Packages  #
#########################

################
#Functions     #
################
library(plotrix)
library(xtable)

path <- "I:/SASTOOLS/outputs/"

#plot function
g.plot<-function(subjects, exp, ncov, ever, uc)
{
  #load data for scenarios without unmeasured confounding (uc=0) and with unmeasured confounding (uc=1)
  if (uc==0)
  {  
    dat1a<-read.csv(file=paste(path,"results_",subjects,"_psi",exp,"_",1,"_ever",ever,".csv",sep=""))
    dat2a<-read.csv(file=paste(path,"results_",subjects,"_psi",exp,"_",2,"_ever",ever,".csv",sep=""))
    dat3a<-read.csv(file=paste(path,"results_",subjects,"_psi",exp,"_",3,"_ever",ever,".csv",sep=""))
  }
  else 
  {
    dat1a<-read.csv(file=paste(path,"results_u_",subjects,"_psi",exp,"_",1,"_ever",ever,".csv",sep=""))
    dat2a<-read.csv(file=paste(path,"results_u_",subjects,"_psi",exp,"_",2,"_ever",ever,".csv",sep=""))
    dat3a<-read.csv(file=paste(path,"results_u_",subjects,"_psi",exp,"_",3,"_ever",ever,".csv",sep=""))
  }
  
  #remove erroneous simulations, indicated by extremely large treatment effects
  dat1<-dat1a[which(abs(dat1a$TREAT)<10),]
  dat2<-dat2a[which(abs(dat2a$TREAT)<10),]
  dat3<-dat3a[which(abs(dat3a$TREAT)<10),]
  #keep number of correct simulations
  n.dat1<-nrow(dat1)
  n.dat2<-nrow(dat2)
  n.dat3<-nrow(dat3)
  if (exp==1)
  {
    #coverage rate for treatment beta=-0.3
    #for both old (robust) and new (non-robust) variance formulas and the three different number of confounders
    if (uc==0)
    {
    dat1$coverage.old<-(abs((dat1$TREAT+0.3)/sqrt(dat1$VAR1))<qnorm(0.975))
    dat1$coverage.new<-(abs((dat1$TREAT+0.3)/sqrt(dat1$VAR2))<qnorm(0.975))
    out1<-c(1,sum(dat1$coverage.old)/n.dat1,sum(dat1$coverage.new)/n.dat1,round(mean(dat1$TREAT+0.3),digits=3))
    }
    else
    {
      #scenario of unmeasured confounding was not conducted for 1 confounder 
      out1<-c(1,NA,NA,NA)
    }
    dat2$coverage.old<-(abs((dat2$TREAT+0.3)/sqrt(dat2$VAR1))<qnorm(0.975))
    dat2$coverage.new<-(abs((dat2$TREAT+0.3)/sqrt(dat2$VAR2))<qnorm(0.975))
    out2<-c(2,sum(dat2$coverage.old)/n.dat2,sum(dat2$coverage.new)/n.dat2,round(mean(dat2$TREAT+0.3),digits=3))
    dat3$coverage.old<-(abs((dat3$TREAT+0.3)/sqrt(dat3$VAR1))<qnorm(0.975))
    dat3$coverage.new<-(abs((dat3$TREAT+0.3)/sqrt(dat3$VAR2))<qnorm(0.975))
    out3<-c(3,sum(dat3$coverage.old)/n.dat3,sum(dat3$coverage.new)/n.dat3,round(mean(dat3$TREAT+0.3),digits=3))
    out<-as.data.frame(rbind(out1,out2,out3))
    colnames(out)<-c("N","cover.old","cover.new","bias")
    
    #plot graphs, customize graph output
    if (uc==0)
    {
      plot(as.character(out$N),out$cover.new, type="b",lty=3, ylim=c(0.86,1), yaxt='n', xaxt='n',xlab=NA, ylab=NA)
      axis(side=1, at=c(1,2,3),labels=c("1","5","20"))
      lines(as.character(out$N),out$cover.old, type="b", lty=2)
      abline(h=0.95)
      title(expression(paste(beta," = -0.3", sep="")), line=1)
      yat<-c(0.86,0.88,0.90,0.92,0.94,0.96,0.98,1)
      ylab<-c(0,0.88,0.90,0.92,0.94,0.96,0.98,1)
      axis(2,at=yat,labels=ylab)
      axis.break(2,0.87,style="slash")
    }
    else
    {
      if (subjects==10000)
      {
      plot(as.character(out$N),out$cover.new, type="b",lty=3, ylim=c(0,1), yaxt='n', xaxt='n',xlab=NA, ylab=NA)
      axis(side=1, at=c(1,2,3),labels=c("1","5","20"))
      lines(as.character(out$N),out$cover.old, type="b", lty=2)
      abline(h=0.95)
      title(expression(paste(beta," = -0.3", sep="")), line=1)
      yat<-c(0,0.20,0.40,0.60,0.80,1)
      ylab<-c(0,0.20,0.40,0.60,0.80,1)
      axis(2,at=yat,labels=ylab)
      }
      else
      {
        plot(as.character(out$N),out$cover.new, type="b",lty=3, ylim=c(0.50,1), yaxt='n', xaxt='n',xlab=NA, ylab=NA)
        axis(side=1, at=c(1,2,3),labels=c("1","5","20"))
        lines(as.character(out$N),out$cover.old, type="b", lty=2)
        abline(h=0.95)
        title(expression(paste(beta," = -0.3", sep="")), line=1)
        yat<-c(0.50,0.60,0.70,0.80,0.90,1)
        ylab<-c(0,0.60,0.70,0.80,0.90,1)
        axis(2,at=yat,labels=ylab)
        axis.break(2,0.55,style="slash")
      }
    }    
    return(out)
  }
  else if (exp==2)
  {  
    #see above, beta=0
    if (uc==0)
    {
      dat1$coverage.old<-(abs((dat1$TREAT)/sqrt(dat1$VAR1))<qnorm(0.975))
      dat1$coverage.new<-(abs((dat1$TREAT)/sqrt(dat1$VAR2))<qnorm(0.975))
      out1<-c(1,sum(dat1$coverage.old)/n.dat1,sum(dat1$coverage.new)/n.dat1,round(mean(dat1$TREAT),digits=3))
    }
    else
    {
      out1<-c(1,NA,NA,NA)
    }
    dat2$coverage.old<-(abs((dat2$TREAT)/sqrt(dat2$VAR1))<qnorm(0.975))
    dat2$coverage.new<-(abs((dat2$TREAT)/sqrt(dat2$VAR2))<qnorm(0.975))
    out2<-c(2,sum(dat2$coverage.old)/n.dat2,sum(dat2$coverage.new)/n.dat2,round(mean(dat2$TREAT),digits=3))
    dat3$coverage.old<-(abs((dat3$TREAT)/sqrt(dat3$VAR1))<qnorm(0.975))
    dat3$coverage.new<-(abs((dat3$TREAT)/sqrt(dat3$VAR2))<qnorm(0.975))
    out3<-c(3,sum(dat3$coverage.old)/n.dat3,sum(dat3$coverage.new)/n.dat3,round(mean(dat3$TREAT),digits=3))
    out<-as.data.frame(rbind(out1,out2,out3))
    colnames(out)<-c("N","cover.old","cover.new","bias")
    if (uc==0)
    {
      plot(as.character(out$N),out$cover.new, type="b",lty=3, ylim=c(0.86,1), yaxt='n', xaxt='n',xlab=NA, ylab=NA)
      axis(side=1, at=c(1,2,3),labels=c("1","5","20"))
      lines(as.character(out$N),out$cover.old, type="b", lty=2)
      abline(h=0.95)
      title(expression(paste(beta," = -0.3", sep="")), line=1)
      yat<-c(0.86,0.88,0.90,0.92,0.94,0.96,0.98,1)
      ylab<-c(0,0.88,0.90,0.92,0.94,0.96,0.98,1)
      axis(2,at=yat,labels=ylab)
      axis.break(2,0.87,style="slash")
    }
    else
    {
      if (subjects==10000)
      {
        plot(as.character(out$N),out$cover.new, type="b",lty=3, ylim=c(0,1), yaxt='n', xaxt='n',xlab=NA, ylab=NA)
        axis(side=1, at=c(1,2,3),labels=c("1","5","20"))
        lines(as.character(out$N),out$cover.old, type="b", lty=2)
        abline(h=0.95)
        title(expression(paste(beta," = -0.3", sep="")), line=1)
        yat<-c(0,0.20,0.40,0.60,0.80,1)
        ylab<-c(0,0.20,0.40,0.60,0.80,1)
        axis(2,at=yat,labels=ylab)
      }
      else
      {
        plot(as.character(out$N),out$cover.new, type="b",lty=3, ylim=c(0.50,1), yaxt='n', xaxt='n',xlab=NA, ylab=NA)
        axis(side=1, at=c(1,2,3),labels=c("1","5","20"))
        lines(as.character(out$N),out$cover.old, type="b", lty=2)
        abline(h=0.95)
        title(expression(paste(beta," = -0.3", sep="")), line=1)
        yat<-c(0.50,0.60,0.70,0.80,0.90,1)
        ylab<-c(0,0.60,0.70,0.80,0.90,1)
        axis(2,at=yat,labels=ylab)
        axis.break(2,0.55,style="slash")
      }
    } 
    return(out)     
  }
  else
  {  
    #see above, beta=0.3
    if (uc==0)
    {
    dat1$coverage.old<-(abs((dat1$TREAT-0.3)/sqrt(dat1$VAR1))<qnorm(0.975))
    dat1$coverage.new<-(abs((dat1$TREAT-0.3)/sqrt(dat1$VAR2))<qnorm(0.975))
    out1<-c(1,sum(dat1$coverage.old)/n.dat1,sum(dat1$coverage.new)/n.dat1,round(mean(dat1$TREAT-0.3),digits=3))
    }
    else
    {
      out1<-c(1,NA,NA,NA) 
    }
    dat2$coverage.old<-(abs((dat2$TREAT-0.3)/sqrt(dat2$VAR1))<qnorm(0.975))
    dat2$coverage.new<-(abs((dat2$TREAT-0.3)/sqrt(dat2$VAR2))<qnorm(0.975))
    out2<-c(2,sum(dat2$coverage.old)/n.dat2,sum(dat2$coverage.new)/n.dat2,round(mean(dat2$TREAT-0.3),digits=3))
    dat3$coverage.old<-(abs((dat3$TREAT-0.3)/sqrt(dat3$VAR1))<qnorm(0.975))
    dat3$coverage.new<-(abs((dat3$TREAT-0.3)/sqrt(dat3$VAR2))<qnorm(0.975))
    out3<-c(3,sum(dat3$coverage.old)/n.dat3,sum(dat3$coverage.new)/n.dat3,round(mean(dat3$TREAT-0.3),digits=3))
    out<-as.data.frame(rbind(out1,out2,out3))
    colnames(out)<-c("N","cover.old","cover.new","bias")
    if (uc==0)
    {
      plot(as.character(out$N),out$cover.new, type="b",lty=3, ylim=c(0.86,1), yaxt='n', xaxt='n',xlab=NA, ylab=NA)
      axis(side=1, at=c(1,2,3),labels=c("1","5","20"))
      lines(as.character(out$N),out$cover.old, type="b", lty=2)
      abline(h=0.95)
      title(expression(paste(beta," = -0.3", sep="")), line=1)
      yat<-c(0.86,0.88,0.90,0.92,0.94,0.96,0.98,1)
      ylab<-c(0,0.88,0.90,0.92,0.94,0.96,0.98,1)
      axis(2,at=yat,labels=ylab)
      axis.break(2,0.87,style="slash")
    }
    else
    {
      if (subjects==10000)
      {
        plot(as.character(out$N),out$cover.new, type="b",lty=3, ylim=c(0,1), yaxt='n', xaxt='n',xlab=NA, ylab=NA)
        axis(side=1, at=c(1,2,3),labels=c("1","5","20"))
        lines(as.character(out$N),out$cover.old, type="b", lty=2)
        abline(h=0.95)
        title(expression(paste(beta," = -0.3", sep="")), line=1)
        yat<-c(0,0.20,0.40,0.60,0.80,1)
        ylab<-c(0,0.20,0.40,0.60,0.80,1)
        axis(2,at=yat,labels=ylab)
      }
      else
      {
        plot(as.character(out$N),out$cover.new, type="b",lty=3, ylim=c(0.50,1), yaxt='n', xaxt='n',xlab=NA, ylab=NA)
        axis(side=1, at=c(1,2,3),labels=c("1","5","20"))
        lines(as.character(out$N),out$cover.old, type="b", lty=2)
        abline(h=0.95)
        title(expression(paste(beta," = -0.3", sep="")), line=1)
        yat<-c(0.50,0.60,0.70,0.80,0.90,1)
        ylab<-c(0,0.60,0.70,0.80,0.90,1)
        axis(2,at=yat,labels=ylab)
        axis.break(2,0.55,style="slash")
      }
    } 
    return(out)
  }
}


#plot graphs on a 3*3 frame as in the publication, as .tiff and .jpeg

tiff("G:/2-PhaseTransfer/Ablage/Publikationen/Varianzschtzung MSMs/StatMed/variance_stim_fig1.tiff", width = 10, height = 10, units = 'in', res = 300)
par(mfrow=c(3,3), mai=c(0.5,0.5,0.6,0),oma=c(2,2,2,2))
graph_500_psi1_0<-g.plot(subjects=500, exp=1, ever=0, uc=0)
graph_500_psi2_0<-g.plot(subjects=500, exp=2, ever=0, uc=0)
graph_500_psi3_0<-g.plot(subjects=500, exp=3, ever=0, uc=0)

graph_2500_psi1_0<-g.plot(subjects=2500, exp=1, ever=0, uc=0)
graph_2500_psi2_0<-g.plot(subjects=2500, exp=2, ever=0, uc=0)
graph_2500_psi3_0<-g.plot(subjects=2500, exp=3, ever=0, uc=0)

graph_10000_psi1_0<-g.plot(subjects=10000, exp=1, ever=0, uc=0)
graph_10000_psi2_0<-g.plot(subjects=10000, exp=2, ever=0, uc=0)
graph_10000_psi3_0<-g.plot(subjects=10000, exp=3, ever=0, uc=0)

mtext("Coverage rate", side=2, line=-1, outer = TRUE)
mtext("Sample size: 500", side=3, line=-2, outer = TRUE)
mtext("Sample size: 2,500", side=3, line=-26, outer = TRUE)
mtext("Sample size: 10,000", side = 3, line = -50, outer = TRUE)
mtext("Number of covariates", side=1, line=-1, outer = TRUE)
dev.off()

tiff("G:/2-PhaseTransfer/Ablage/Publikationen/Varianzschtzung MSMs/StatMed/variance_stim_fig2.tiff", width = 10, height = 10, units = 'in', res = 300)
par(mfrow=c(3,3), mai=c(0.5,0.5,0.6,0),oma=c(2,2,2,2))
graph_500_psi1_1<-g.plot(subjects=500, exp=1, ever=1, uc=0)
graph_500_psi2_1<-g.plot(subjects=500, exp=2, ever=1, uc=0)
graph_500_psi3_1<-g.plot(subjects=500, exp=3, ever=1, uc=0)

graph_2500_psi1_1<-g.plot(subjects=2500, exp=1, ever=1, uc=0)
graph_2500_psi2_1<-g.plot(subjects=2500, exp=2, ever=1, uc=0)
graph_2500_psi3_1<-g.plot(subjects=2500, exp=3, ever=1, uc=0)

graph_10000_psi1_1<-g.plot(subjects=10000, exp=1, ever=1, uc=0)
graph_10000_psi2_1<-g.plot(subjects=10000, exp=2, ever=1, uc=0)
graph_10000_psi3_1<-g.plot(subjects=10000, exp=3, ever=1, uc=0)

mtext("Coverage rate", side=2, line=-1, outer = TRUE)
mtext("Sample size: 500", side=3, line=-2, outer = TRUE)
mtext("Sample size: 2,500", side=3, line=-26, outer = TRUE)
mtext("Sample size: 10,000", side = 3, line = -50, outer = TRUE)
mtext("Number of covariates", side=1, line=-1, outer = TRUE)
dev.off()

tiff("G:/2-PhaseTransfer/Ablage/Publikationen/Varianzschtzung MSMs/StatMed/variance_stim_fig3.tiff", width = 10, height = 10, units = 'in', res = 300)
par(mfrow=c(3,3), mai=c(0.5,0.5,0.6,0),oma=c(2,2,2,2))
graph_500_psi1_0_u<-g.plot(subjects=500, exp=1, ever=0, uc=1)
graph_500_psi2_0_u<-g.plot(subjects=500, exp=2, ever=0, uc=1)
graph_500_psi3_0_u<-g.plot(subjects=500, exp=3, ever=0, uc=1)

graph_2500_psi1_0_u<-g.plot(subjects=2500, exp=1, ever=0, uc=1)
graph_2500_psi2_0_u<-g.plot(subjects=2500, exp=2, ever=0, uc=1)
graph_2500_psi3_0_u<-g.plot(subjects=2500, exp=3, ever=0, uc=1)

graph_10000_psi1_0_u<-g.plot(subjects=10000, exp=1, ever=0, uc=1)
graph_10000_psi2_0_u<-g.plot(subjects=10000, exp=2, ever=0, uc=1)
graph_10000_psi3_0_u<-g.plot(subjects=10000, exp=3, ever=0, uc=1)
mtext("Coverage rate", side=2, line=-1, outer = TRUE)
mtext("Sample size: 500", side=3, line=-2, outer = TRUE)
mtext("Sample size: 2,500", side=3, line=-26, outer = TRUE)
mtext("Sample size: 10,000", side = 3, line = -50, outer = TRUE)
mtext("Number of covariates", side=1, line=-1, outer = TRUE)
dev.off()

tiff("G:/2-PhaseTransfer/Ablage/Publikationen/Varianzschtzung MSMs/StatMed/variance_stim_fig4.tiff", width = 10, height = 10, units = 'in', res = 300)
par(mfrow=c(3,3), mai=c(0.5,0.5,0.6,0),oma=c(2,2,2,2))
graph_500_psi1_1_u<-g.plot(subjects=500, exp=1, ever=1, uc=1)
graph_500_psi2_1_u<-g.plot(subjects=500, exp=2, ever=1, uc=1)
graph_500_psi3_1_u<-g.plot(subjects=500, exp=3, ever=1, uc=1)

graph_2500_psi1_1_u<-g.plot(subjects=2500, exp=1, ever=1, uc=1)
graph_2500_psi2_1_u<-g.plot(subjects=2500, exp=2, ever=1, uc=1)
graph_2500_psi3_1_u<-g.plot(subjects=2500, exp=3, ever=1, uc=1)

graph_10000_psi1_1_u<-g.plot(subjects=10000, exp=1, ever=1, uc=1)
graph_10000_psi2_1_u<-g.plot(subjects=10000, exp=2, ever=1, uc=1)
graph_10000_psi3_1_u<-g.plot(subjects=10000, exp=3, ever=1, uc=1)
mtext("Coverage rate", side=2, line=-1, outer = TRUE)
mtext("Sample size: 500", side=3, line=-2, outer = TRUE)
mtext("Sample size: 2,500", side=3, line=-26, outer = TRUE)
mtext("Sample size: 10,000", side = 3, line = -50, outer = TRUE)
mtext("Number of covariates", side=1, line=-1, outer = TRUE)
dev.off()

jpeg("G:/2-PhaseTransfer/Ablage/Publikationen/Varianzschtzung MSMs/StatMed/variance_stim_fig1.jpg", width = 10, height = 10, units = 'in', res = 300)
par(mfrow=c(3,3), mai=c(0.5,0.5,0.6,0),oma=c(2,2,2,2))
graph_500_psi1_0<-g.plot(subjects=500, exp=1, ever=0, uc=0)
graph_500_psi2_0<-g.plot(subjects=500, exp=2, ever=0, uc=0)
graph_500_psi3_0<-g.plot(subjects=500, exp=3, ever=0, uc=0)

graph_2500_psi1_0<-g.plot(subjects=2500, exp=1, ever=0, uc=0)
graph_2500_psi2_0<-g.plot(subjects=2500, exp=2, ever=0, uc=0)
graph_2500_psi3_0<-g.plot(subjects=2500, exp=3, ever=0, uc=0)

graph_10000_psi1_0<-g.plot(subjects=10000, exp=1, ever=0, uc=0)
graph_10000_psi2_0<-g.plot(subjects=10000, exp=2, ever=0, uc=0)
graph_10000_psi3_0<-g.plot(subjects=10000, exp=3, ever=0, uc=0)

mtext("Coverage rate", side=2, line=-1, outer = TRUE)
mtext("Sample size: 500", side=3, line=-2, outer = TRUE)
mtext("Sample size: 2,500", side=3, line=-26, outer = TRUE)
mtext("Sample size: 10,000", side = 3, line = -50, outer = TRUE)
mtext("Number of covariates", side=1, line=-1, outer = TRUE)
dev.off()

jpeg("G:/2-PhaseTransfer/Ablage/Publikationen/Varianzschtzung MSMs/StatMed/variance_stim_fig2.jpg", width = 10, height = 10, units = 'in', res = 300)
par(mfrow=c(3,3), mai=c(0.5,0.5,0.6,0),oma=c(2,2,2,2))
graph_500_psi1_1<-g.plot(subjects=500, exp=1, ever=1, uc=0)
graph_500_psi2_1<-g.plot(subjects=500, exp=2, ever=1, uc=0)
graph_500_psi3_1<-g.plot(subjects=500, exp=3, ever=1, uc=0)

graph_2500_psi1_1<-g.plot(subjects=2500, exp=1, ever=1, uc=0)
graph_2500_psi2_1<-g.plot(subjects=2500, exp=2, ever=1, uc=0)
graph_2500_psi3_1<-g.plot(subjects=2500, exp=3, ever=1, uc=0)

graph_10000_psi1_1<-g.plot(subjects=10000, exp=1, ever=1, uc=0)
graph_10000_psi2_1<-g.plot(subjects=10000, exp=2, ever=1, uc=0)
graph_10000_psi3_1<-g.plot(subjects=10000, exp=3, ever=1, uc=0)

mtext("Coverage rate", side=2, line=-1, outer = TRUE)
mtext("Sample size: 500", side=3, line=-2, outer = TRUE)
mtext("Sample size: 2,500", side=3, line=-26, outer = TRUE)
mtext("Sample size: 10,000", side = 3, line = -50, outer = TRUE)
mtext("Number of covariates", side=1, line=-1, outer = TRUE)
dev.off()

jpeg("G:/2-PhaseTransfer/Ablage/Publikationen/Varianzschtzung MSMs/StatMed/variance_stim_fig3.jpg", width = 10, height = 10, units = 'in', res = 300)
par(mfrow=c(3,3), mai=c(0.5,0.5,0.6,0),oma=c(2,2,2,2))
graph_500_psi1_0_u<-g.plot(subjects=500, exp=1, ever=0, uc=1)
graph_500_psi2_0_u<-g.plot(subjects=500, exp=2, ever=0, uc=1)
graph_500_psi3_0_u<-g.plot(subjects=500, exp=3, ever=0, uc=1)

graph_2500_psi1_0_u<-g.plot(subjects=2500, exp=1, ever=0, uc=1)
graph_2500_psi2_0_u<-g.plot(subjects=2500, exp=2, ever=0, uc=1)
graph_2500_psi3_0_u<-g.plot(subjects=2500, exp=3, ever=0, uc=1)

graph_10000_psi1_0_u<-g.plot(subjects=10000, exp=1, ever=0, uc=1)
graph_10000_psi2_0_u<-g.plot(subjects=10000, exp=2, ever=0, uc=1)
graph_10000_psi3_0_u<-g.plot(subjects=10000, exp=3, ever=0, uc=1)
mtext("Coverage rate", side=2, line=-1, outer = TRUE)
mtext("Sample size: 500", side=3, line=-2, outer = TRUE)
mtext("Sample size: 2,500", side=3, line=-26, outer = TRUE)
mtext("Sample size: 10,000", side = 3, line = -50, outer = TRUE)
mtext("Number of covariates", side=1, line=-1, outer = TRUE)
dev.off()

jpeg("G:/2-PhaseTransfer/Ablage/Publikationen/Varianzschtzung MSMs/StatMed/variance_stim_fig4.jpg", width = 10, height = 10, units = 'in', res = 300)
par(mfrow=c(3,3), mai=c(0.5,0.5,0.6,0),oma=c(2,2,2,2))
graph_500_psi1_1_u<-g.plot(subjects=500, exp=1, ever=1, uc=1)
graph_500_psi2_1_u<-g.plot(subjects=500, exp=2, ever=1, uc=1)
graph_500_psi3_1_u<-g.plot(subjects=500, exp=3, ever=1, uc=1)

graph_2500_psi1_1_u<-g.plot(subjects=2500, exp=1, ever=1, uc=1)
graph_2500_psi2_1_u<-g.plot(subjects=2500, exp=2, ever=1, uc=1)
graph_2500_psi3_1_u<-g.plot(subjects=2500, exp=3, ever=1, uc=1)

graph_10000_psi1_1_u<-g.plot(subjects=10000, exp=1, ever=1, uc=1)
graph_10000_psi2_1_u<-g.plot(subjects=10000, exp=2, ever=1, uc=1)
graph_10000_psi3_1_u<-g.plot(subjects=10000, exp=3, ever=1, uc=1)
mtext("Coverage rate", side=2, line=-1, outer = TRUE)
mtext("Sample size: 500", side=3, line=-2, outer = TRUE)
mtext("Sample size: 2,500", side=3, line=-26, outer = TRUE)
mtext("Sample size: 10,000", side = 3, line = -50, outer = TRUE)
mtext("Number of covariates", side=1, line=-1, outer = TRUE)
dev.off()


#calculation of elements in Table 3 of the publication
table<-rbind(
  c(0,0,500,-0.3,
    graph_500_psi1_0$bias[which(graph_500_psi1_0$N==1)],
    graph_500_psi1_0$bias[which(graph_500_psi1_0$N==2)],
    graph_500_psi1_0$bias[which(graph_500_psi1_0$N==3)],
    graph_500_psi1_0$cover.old[which(graph_500_psi1_0$N==1)],
    graph_500_psi1_0$cover.old[which(graph_500_psi1_0$N==2)],
    graph_500_psi1_0$cover.old[which(graph_500_psi1_0$N==3)],
    graph_500_psi1_0$cover.new[which(graph_500_psi1_0$N==1)],
    graph_500_psi1_0$cover.new[which(graph_500_psi1_0$N==2)],
    graph_500_psi1_0$cover.new[which(graph_500_psi1_0$N==3)]),
  c(0,0,500, 0,
    graph_500_psi2_0$bias[which(graph_500_psi2_0$N==1)],
    graph_500_psi2_0$bias[which(graph_500_psi2_0$N==2)],
    graph_500_psi2_0$bias[which(graph_500_psi2_0$N==3)],
    graph_500_psi2_0$cover.old[which(graph_500_psi2_0$N==1)],
    graph_500_psi2_0$cover.old[which(graph_500_psi2_0$N==2)],
    graph_500_psi2_0$cover.old[which(graph_500_psi2_0$N==3)],
    graph_500_psi2_0$cover.new[which(graph_500_psi2_0$N==1)],
    graph_500_psi2_0$cover.new[which(graph_500_psi2_0$N==2)],
    graph_500_psi2_0$cover.new[which(graph_500_psi2_0$N==3)]),
  c(0,0,500,0.3,
    graph_500_psi3_0$bias[which(graph_500_psi3_0$N==1)],
    graph_500_psi3_0$bias[which(graph_500_psi3_0$N==2)],
    graph_500_psi3_0$bias[which(graph_500_psi3_0$N==3)],
    graph_500_psi3_0$cover.old[which(graph_500_psi3_0$N==1)],
    graph_500_psi3_0$cover.old[which(graph_500_psi3_0$N==2)],
    graph_500_psi3_0$cover.old[which(graph_500_psi3_0$N==3)],
    graph_500_psi3_0$cover.new[which(graph_500_psi3_0$N==1)],
    graph_500_psi3_0$cover.new[which(graph_500_psi3_0$N==2)],
    graph_500_psi3_0$cover.new[which(graph_500_psi3_0$N==3)]),
  c(0,0,2500,-0.3,
    graph_2500_psi1_0$bias[which(graph_2500_psi1_0$N==1)],
    graph_2500_psi1_0$bias[which(graph_2500_psi1_0$N==2)],
    graph_2500_psi1_0$bias[which(graph_2500_psi1_0$N==3)],
    graph_2500_psi1_0$cover.old[which(graph_2500_psi1_0$N==1)],
    graph_2500_psi1_0$cover.old[which(graph_2500_psi1_0$N==2)],
    graph_2500_psi1_0$cover.old[which(graph_2500_psi1_0$N==3)],
    graph_2500_psi1_0$cover.new[which(graph_2500_psi1_0$N==1)],
    graph_2500_psi1_0$cover.new[which(graph_2500_psi1_0$N==2)],
    graph_2500_psi1_0$cover.new[which(graph_2500_psi1_0$N==3)]),
  c(0,0,2500, 0,
    graph_2500_psi2_0$bias[which(graph_2500_psi2_0$N==1)],
    graph_2500_psi2_0$bias[which(graph_2500_psi2_0$N==2)],
    graph_2500_psi2_0$bias[which(graph_2500_psi2_0$N==3)],
    graph_2500_psi2_0$cover.old[which(graph_2500_psi2_0$N==1)],
    graph_2500_psi2_0$cover.old[which(graph_2500_psi2_0$N==2)],
    graph_2500_psi2_0$cover.old[which(graph_2500_psi2_0$N==3)],
    graph_2500_psi2_0$cover.new[which(graph_2500_psi2_0$N==1)],
    graph_2500_psi2_0$cover.new[which(graph_2500_psi2_0$N==2)],
    graph_2500_psi2_0$cover.new[which(graph_2500_psi2_0$N==3)]),
  c(0,0,2500,0.3,
    graph_2500_psi3_0$bias[which(graph_2500_psi3_0$N==1)],
    graph_2500_psi3_0$bias[which(graph_2500_psi3_0$N==2)],
    graph_2500_psi3_0$bias[which(graph_2500_psi3_0$N==3)],
    graph_2500_psi3_0$cover.old[which(graph_2500_psi3_0$N==1)],
    graph_2500_psi3_0$cover.old[which(graph_2500_psi3_0$N==2)],
    graph_2500_psi3_0$cover.old[which(graph_2500_psi3_0$N==3)],
    graph_2500_psi3_0$cover.new[which(graph_2500_psi3_0$N==1)],
    graph_2500_psi3_0$cover.new[which(graph_2500_psi3_0$N==2)],
    graph_2500_psi3_0$cover.new[which(graph_2500_psi3_0$N==3)]),
  c(0,0,10000,-0.3,
    graph_10000_psi1_0$bias[which(graph_10000_psi1_0$N==1)],
    graph_10000_psi1_0$bias[which(graph_10000_psi1_0$N==2)],
    graph_10000_psi1_0$bias[which(graph_10000_psi1_0$N==3)],
    graph_10000_psi1_0$cover.old[which(graph_10000_psi1_0$N==1)],
    graph_10000_psi1_0$cover.old[which(graph_10000_psi1_0$N==2)],
    graph_10000_psi1_0$cover.old[which(graph_10000_psi1_0$N==3)],
    graph_10000_psi1_0$cover.new[which(graph_10000_psi1_0$N==1)],
    graph_10000_psi1_0$cover.new[which(graph_10000_psi1_0$N==2)],
    graph_10000_psi1_0$cover.new[which(graph_10000_psi1_0$N==3)]),
  c(0,0,10000, 0,
    graph_10000_psi2_0$bias[which(graph_10000_psi2_0$N==1)],
    graph_10000_psi2_0$bias[which(graph_10000_psi2_0$N==2)],
    graph_10000_psi2_0$bias[which(graph_10000_psi2_0$N==3)],
    graph_10000_psi2_0$cover.old[which(graph_10000_psi2_0$N==1)],
    graph_10000_psi2_0$cover.old[which(graph_10000_psi2_0$N==2)],
    graph_10000_psi2_0$cover.old[which(graph_10000_psi2_0$N==3)],
    graph_10000_psi2_0$cover.new[which(graph_10000_psi2_0$N==1)],
    graph_10000_psi2_0$cover.new[which(graph_10000_psi2_0$N==2)],
    graph_10000_psi2_0$cover.new[which(graph_10000_psi2_0$N==3)]),
  c(0,0,10000,0.3,
    graph_10000_psi3_0$bias[which(graph_10000_psi3_0$N==1)],
    graph_10000_psi3_0$bias[which(graph_10000_psi3_0$N==2)],
    graph_10000_psi3_0$bias[which(graph_10000_psi3_0$N==3)],
    graph_10000_psi3_0$cover.old[which(graph_10000_psi3_0$N==1)],
    graph_10000_psi3_0$cover.old[which(graph_10000_psi3_0$N==2)],
    graph_10000_psi3_0$cover.old[which(graph_10000_psi3_0$N==3)],
    graph_10000_psi3_0$cover.new[which(graph_10000_psi3_0$N==1)],
    graph_10000_psi3_0$cover.new[which(graph_10000_psi3_0$N==2)],
    graph_10000_psi3_0$cover.new[which(graph_10000_psi3_0$N==3)]),
  
  c(0,1,500,-0.3,
    graph_500_psi1_1$bias[which(graph_500_psi1_1$N==1)],
    graph_500_psi1_1$bias[which(graph_500_psi1_1$N==2)],
    graph_500_psi1_1$bias[which(graph_500_psi1_1$N==3)],
    graph_500_psi1_1$cover.old[which(graph_500_psi1_1$N==1)],
    graph_500_psi1_1$cover.old[which(graph_500_psi1_1$N==2)],
    graph_500_psi1_1$cover.old[which(graph_500_psi1_1$N==3)],
    graph_500_psi1_1$cover.new[which(graph_500_psi1_1$N==1)],
    graph_500_psi1_1$cover.new[which(graph_500_psi1_1$N==2)],
    graph_500_psi1_1$cover.new[which(graph_500_psi1_1$N==3)]),
  c(0,1,500, 0,
    graph_500_psi2_1$bias[which(graph_500_psi2_1$N==1)],
    graph_500_psi2_1$bias[which(graph_500_psi2_1$N==2)],
    graph_500_psi2_1$bias[which(graph_500_psi2_1$N==3)],
    graph_500_psi2_1$cover.old[which(graph_500_psi2_1$N==1)],
    graph_500_psi2_1$cover.old[which(graph_500_psi2_1$N==2)],
    graph_500_psi2_1$cover.old[which(graph_500_psi2_1$N==3)],
    graph_500_psi2_1$cover.new[which(graph_500_psi2_1$N==1)],
    graph_500_psi2_1$cover.new[which(graph_500_psi2_1$N==2)],
    graph_500_psi2_1$cover.new[which(graph_500_psi2_1$N==3)]),
  c(0,1,500,0.3,
    graph_500_psi3_1$bias[which(graph_500_psi3_1$N==1)],
    graph_500_psi3_1$bias[which(graph_500_psi3_1$N==2)],
    graph_500_psi3_1$bias[which(graph_500_psi3_1$N==3)],
    graph_500_psi3_1$cover.old[which(graph_500_psi3_1$N==1)],
    graph_500_psi3_1$cover.old[which(graph_500_psi3_1$N==2)],
    graph_500_psi3_1$cover.old[which(graph_500_psi3_1$N==3)],
    graph_500_psi3_1$cover.new[which(graph_500_psi3_1$N==1)],
    graph_500_psi3_1$cover.new[which(graph_500_psi3_1$N==2)],
    graph_500_psi3_1$cover.new[which(graph_500_psi3_1$N==3)]),
  
  c(0,1,2500,-0.3,
    graph_2500_psi1_1$bias[which(graph_2500_psi1_1$N==1)],
    graph_2500_psi1_1$bias[which(graph_2500_psi1_1$N==2)],
    graph_2500_psi1_1$bias[which(graph_2500_psi1_1$N==3)],
    graph_2500_psi1_1$cover.old[which(graph_2500_psi1_1$N==1)],
    graph_2500_psi1_1$cover.old[which(graph_2500_psi1_1$N==2)],
    graph_2500_psi1_1$cover.old[which(graph_2500_psi1_1$N==3)],
    graph_2500_psi1_1$cover.new[which(graph_2500_psi1_1$N==1)],
    graph_2500_psi1_1$cover.new[which(graph_2500_psi1_1$N==2)],
    graph_2500_psi1_1$cover.new[which(graph_2500_psi1_1$N==3)]),
  c(0,1,2500, 0,
    graph_2500_psi2_1$bias[which(graph_2500_psi2_1$N==1)],
    graph_2500_psi2_1$bias[which(graph_2500_psi2_1$N==2)],
    graph_2500_psi2_1$bias[which(graph_2500_psi2_1$N==3)],
    graph_2500_psi2_1$cover.old[which(graph_2500_psi2_1$N==1)],
    graph_2500_psi2_1$cover.old[which(graph_2500_psi2_1$N==2)],
    graph_2500_psi2_1$cover.old[which(graph_2500_psi2_1$N==3)],
    graph_2500_psi2_1$cover.new[which(graph_2500_psi2_1$N==1)],
    graph_2500_psi2_1$cover.new[which(graph_2500_psi2_1$N==2)],
    graph_2500_psi2_1$cover.new[which(graph_2500_psi2_1$N==3)]),
  c(0,1,2500,0.3,
    graph_2500_psi3_1$bias[which(graph_2500_psi3_1$N==1)],
    graph_2500_psi3_1$bias[which(graph_2500_psi3_1$N==2)],
    graph_2500_psi3_1$bias[which(graph_2500_psi3_1$N==3)],
    graph_2500_psi3_1$cover.old[which(graph_2500_psi3_1$N==1)],
    graph_2500_psi3_1$cover.old[which(graph_2500_psi3_1$N==2)],
    graph_2500_psi3_1$cover.old[which(graph_2500_psi3_1$N==3)],
    graph_2500_psi3_1$cover.new[which(graph_2500_psi3_1$N==1)],
    graph_2500_psi3_1$cover.new[which(graph_2500_psi3_1$N==2)],
    graph_2500_psi3_1$cover.new[which(graph_2500_psi3_1$N==3)]),
  
  c(0,1,10000,-0.3,
    graph_10000_psi1_1$bias[which(graph_10000_psi1_1$N==1)],
    graph_10000_psi1_1$bias[which(graph_10000_psi1_1$N==2)],
    graph_10000_psi1_1$bias[which(graph_10000_psi1_1$N==3)],
    graph_10000_psi1_1$cover.old[which(graph_10000_psi1_1$N==1)],
    graph_10000_psi1_1$cover.old[which(graph_10000_psi1_1$N==2)],
    graph_10000_psi1_1$cover.old[which(graph_10000_psi1_1$N==3)],
    graph_10000_psi1_1$cover.new[which(graph_10000_psi1_1$N==1)],
    graph_10000_psi1_1$cover.new[which(graph_10000_psi1_1$N==2)],
    graph_10000_psi1_1$cover.new[which(graph_10000_psi1_1$N==3)]),
  c(0,1,10000, 0,
    graph_10000_psi2_1$bias[which(graph_10000_psi2_1$N==1)],
    graph_10000_psi2_1$bias[which(graph_10000_psi2_1$N==2)],
    graph_10000_psi2_1$bias[which(graph_10000_psi2_1$N==3)],
    graph_10000_psi2_1$cover.old[which(graph_10000_psi2_1$N==1)],
    graph_10000_psi2_1$cover.old[which(graph_10000_psi2_1$N==2)],
    graph_10000_psi2_1$cover.old[which(graph_10000_psi2_1$N==3)],
    graph_10000_psi2_1$cover.new[which(graph_10000_psi2_1$N==1)],
    graph_10000_psi2_1$cover.new[which(graph_10000_psi2_1$N==2)],
    graph_10000_psi2_1$cover.new[which(graph_10000_psi2_1$N==3)]),
  c(0,1,10000,0.3,
    graph_10000_psi3_1$bias[which(graph_10000_psi3_1$N==1)],
    graph_10000_psi3_1$bias[which(graph_10000_psi3_1$N==2)],
    graph_10000_psi3_1$bias[which(graph_10000_psi3_1$N==3)],
    graph_10000_psi3_1$cover.old[which(graph_10000_psi3_1$N==1)],
    graph_10000_psi3_1$cover.old[which(graph_10000_psi3_1$N==2)],
    graph_10000_psi3_1$cover.old[which(graph_10000_psi3_1$N==3)],
    graph_10000_psi3_1$cover.new[which(graph_10000_psi3_1$N==1)],
    graph_10000_psi3_1$cover.new[which(graph_10000_psi3_1$N==2)],
    graph_10000_psi3_1$cover.new[which(graph_10000_psi3_1$N==3)]),
  
  
  c(1,0,500,-0.3,
    graph_500_psi1_0_u$bias[which(graph_500_psi1_0_u$N==1)],
    graph_500_psi1_0_u$bias[which(graph_500_psi1_0_u$N==2)],
    graph_500_psi1_0_u$bias[which(graph_500_psi1_0_u$N==3)],
    graph_500_psi1_0_u$cover.old[which(graph_500_psi1_0_u$N==1)],
    graph_500_psi1_0_u$cover.old[which(graph_500_psi1_0_u$N==2)],
    graph_500_psi1_0_u$cover.old[which(graph_500_psi1_0_u$N==3)],
    graph_500_psi1_0_u$cover.new[which(graph_500_psi1_0_u$N==1)],
    graph_500_psi1_0_u$cover.new[which(graph_500_psi1_0_u$N==2)],
    graph_500_psi1_0_u$cover.new[which(graph_500_psi1_0_u$N==3)]),
  c(1,0,500, 0,
    graph_500_psi2_0_u$bias[which(graph_500_psi2_0_u$N==1)],
    graph_500_psi2_0_u$bias[which(graph_500_psi2_0_u$N==2)],
    graph_500_psi2_0_u$bias[which(graph_500_psi2_0_u$N==3)],
    graph_500_psi2_0_u$cover.old[which(graph_500_psi2_0_u$N==1)],
    graph_500_psi2_0_u$cover.old[which(graph_500_psi2_0_u$N==2)],
    graph_500_psi2_0_u$cover.old[which(graph_500_psi2_0_u$N==3)],
    graph_500_psi2_0_u$cover.new[which(graph_500_psi2_0_u$N==1)],
    graph_500_psi2_0_u$cover.new[which(graph_500_psi2_0_u$N==2)],
    graph_500_psi2_0_u$cover.new[which(graph_500_psi2_0_u$N==3)]),
  c(1,0,500,0.3,
    graph_500_psi3_0_u$bias[which(graph_500_psi3_0_u$N==1)],
    graph_500_psi3_0_u$bias[which(graph_500_psi3_0_u$N==2)],
    graph_500_psi3_0_u$bias[which(graph_500_psi3_0_u$N==3)],
    graph_500_psi3_0_u$cover.old[which(graph_500_psi3_0_u$N==1)],
    graph_500_psi3_0_u$cover.old[which(graph_500_psi3_0_u$N==2)],
    graph_500_psi3_0_u$cover.old[which(graph_500_psi3_0_u$N==3)],
    graph_500_psi3_0_u$cover.new[which(graph_500_psi3_0_u$N==1)],
    graph_500_psi3_0_u$cover.new[which(graph_500_psi3_0_u$N==2)],
    graph_500_psi3_0_u$cover.new[which(graph_500_psi3_0_u$N==3)]),
  c(1,0,2500,-0.3,
    graph_2500_psi1_0_u$bias[which(graph_2500_psi1_0_u$N==1)],
    graph_2500_psi1_0_u$bias[which(graph_2500_psi1_0_u$N==2)],
    graph_2500_psi1_0_u$bias[which(graph_2500_psi1_0_u$N==3)],
    graph_2500_psi1_0_u$cover.old[which(graph_2500_psi1_0_u$N==1)],
    graph_2500_psi1_0_u$cover.old[which(graph_2500_psi1_0_u$N==2)],
    graph_2500_psi1_0_u$cover.old[which(graph_2500_psi1_0_u$N==3)],
    graph_2500_psi1_0_u$cover.new[which(graph_2500_psi1_0_u$N==1)],
    graph_2500_psi1_0_u$cover.new[which(graph_2500_psi1_0_u$N==2)],
    graph_2500_psi1_0_u$cover.new[which(graph_2500_psi1_0_u$N==3)]),
  c(1,0,2500, 0,
    graph_2500_psi2_0_u$bias[which(graph_2500_psi2_0_u$N==1)],
    graph_2500_psi2_0_u$bias[which(graph_2500_psi2_0_u$N==2)],
    graph_2500_psi2_0_u$bias[which(graph_2500_psi2_0_u$N==3)],
    graph_2500_psi2_0_u$cover.old[which(graph_2500_psi2_0_u$N==1)],
    graph_2500_psi2_0_u$cover.old[which(graph_2500_psi2_0_u$N==2)],
    graph_2500_psi2_0_u$cover.old[which(graph_2500_psi2_0_u$N==3)],
    graph_2500_psi2_0_u$cover.new[which(graph_2500_psi2_0_u$N==1)],
    graph_2500_psi2_0_u$cover.new[which(graph_2500_psi2_0_u$N==2)],
    graph_2500_psi2_0_u$cover.new[which(graph_2500_psi2_0_u$N==3)]),
  c(1,0,2500,0.3,
    graph_2500_psi3_0_u$bias[which(graph_2500_psi3_0_u$N==1)],
    graph_2500_psi3_0_u$bias[which(graph_2500_psi3_0_u$N==2)],
    graph_2500_psi3_0_u$bias[which(graph_2500_psi3_0_u$N==3)],
    graph_2500_psi3_0_u$cover.old[which(graph_2500_psi3_0_u$N==1)],
    graph_2500_psi3_0_u$cover.old[which(graph_2500_psi3_0_u$N==2)],
    graph_2500_psi3_0_u$cover.old[which(graph_2500_psi3_0_u$N==3)],
    graph_2500_psi3_0_u$cover.new[which(graph_2500_psi3_0_u$N==1)],
    graph_2500_psi3_0_u$cover.new[which(graph_2500_psi3_0_u$N==2)],
    graph_2500_psi3_0_u$cover.new[which(graph_2500_psi3_0_u$N==3)]),
  c(1,0,10000,-0.3,
    graph_10000_psi1_0_u$bias[which(graph_10000_psi1_0_u$N==1)],
    graph_10000_psi1_0_u$bias[which(graph_10000_psi1_0_u$N==2)],
    graph_10000_psi1_0_u$bias[which(graph_10000_psi1_0_u$N==3)],
    graph_10000_psi1_0_u$cover.old[which(graph_10000_psi1_0_u$N==1)],
    graph_10000_psi1_0_u$cover.old[which(graph_10000_psi1_0_u$N==2)],
    graph_10000_psi1_0_u$cover.old[which(graph_10000_psi1_0_u$N==3)],
    graph_10000_psi1_0_u$cover.new[which(graph_10000_psi1_0_u$N==1)],
    graph_10000_psi1_0_u$cover.new[which(graph_10000_psi1_0_u$N==2)],
    graph_10000_psi1_0_u$cover.new[which(graph_10000_psi1_0_u$N==3)]),
  c(1,0,10000, 0,
    graph_10000_psi2_0_u$bias[which(graph_10000_psi2_0_u$N==1)],
    graph_10000_psi2_0_u$bias[which(graph_10000_psi2_0_u$N==2)],
    graph_10000_psi2_0_u$bias[which(graph_10000_psi2_0_u$N==3)],
    graph_10000_psi2_0_u$cover.old[which(graph_10000_psi2_0_u$N==1)],
    graph_10000_psi2_0_u$cover.old[which(graph_10000_psi2_0_u$N==2)],
    graph_10000_psi2_0_u$cover.old[which(graph_10000_psi2_0_u$N==3)],
    graph_10000_psi2_0_u$cover.new[which(graph_10000_psi2_0_u$N==1)],
    graph_10000_psi2_0_u$cover.new[which(graph_10000_psi2_0_u$N==2)],
    graph_10000_psi2_0_u$cover.new[which(graph_10000_psi2_0_u$N==3)]),
  c(1,0,10000,0.3,
    graph_10000_psi3_0_u$bias[which(graph_10000_psi3_0_u$N==1)],
    graph_10000_psi3_0_u$bias[which(graph_10000_psi3_0_u$N==2)],
    graph_10000_psi3_0_u$bias[which(graph_10000_psi3_0_u$N==3)],
    graph_10000_psi3_0_u$cover.old[which(graph_10000_psi3_0_u$N==1)],
    graph_10000_psi3_0_u$cover.old[which(graph_10000_psi3_0_u$N==2)],
    graph_10000_psi3_0_u$cover.old[which(graph_10000_psi3_0_u$N==3)],
    graph_10000_psi3_0_u$cover.new[which(graph_10000_psi3_0_u$N==1)],
    graph_10000_psi3_0_u$cover.new[which(graph_10000_psi3_0_u$N==2)],
    graph_10000_psi3_0_u$cover.new[which(graph_10000_psi3_0_u$N==3)]),
  
  c(1,1,500,-0.3,
    graph_500_psi1_1_u$bias[which(graph_500_psi1_1_u$N==1)],
    graph_500_psi1_1_u$bias[which(graph_500_psi1_1_u$N==2)],
    graph_500_psi1_1_u$bias[which(graph_500_psi1_1_u$N==3)],
    graph_500_psi1_1_u$cover.old[which(graph_500_psi1_1_u$N==1)],
    graph_500_psi1_1_u$cover.old[which(graph_500_psi1_1_u$N==2)],
    graph_500_psi1_1_u$cover.old[which(graph_500_psi1_1_u$N==3)],
    graph_500_psi1_1_u$cover.new[which(graph_500_psi1_1_u$N==1)],
    graph_500_psi1_1_u$cover.new[which(graph_500_psi1_1_u$N==2)],
    graph_500_psi1_1_u$cover.new[which(graph_500_psi1_1_u$N==3)]),
  c(1,1,500, 0,
    graph_500_psi2_1_u$bias[which(graph_500_psi2_1_u$N==1)],
    graph_500_psi2_1_u$bias[which(graph_500_psi2_1_u$N==2)],
    graph_500_psi2_1_u$bias[which(graph_500_psi2_1_u$N==3)],
    graph_500_psi2_1_u$cover.old[which(graph_500_psi2_1_u$N==1)],
    graph_500_psi2_1_u$cover.old[which(graph_500_psi2_1_u$N==2)],
    graph_500_psi2_1_u$cover.old[which(graph_500_psi2_1_u$N==3)],
    graph_500_psi2_1_u$cover.new[which(graph_500_psi2_1_u$N==1)],
    graph_500_psi2_1_u$cover.new[which(graph_500_psi2_1_u$N==2)],
    graph_500_psi2_1_u$cover.new[which(graph_500_psi2_1_u$N==3)]),
  c(1,1,500,0.3,
    graph_500_psi3_1_u$bias[which(graph_500_psi3_1_u$N==1)],
    graph_500_psi3_1_u$bias[which(graph_500_psi3_1_u$N==2)],
    graph_500_psi3_1_u$bias[which(graph_500_psi3_1_u$N==3)],
    graph_500_psi3_1_u$cover.old[which(graph_500_psi3_1_u$N==1)],
    graph_500_psi3_1_u$cover.old[which(graph_500_psi3_1_u$N==2)],
    graph_500_psi3_1_u$cover.old[which(graph_500_psi3_1_u$N==3)],
    graph_500_psi3_1_u$cover.new[which(graph_500_psi3_1_u$N==1)],
    graph_500_psi3_1_u$cover.new[which(graph_500_psi3_1_u$N==2)],
    graph_500_psi3_1_u$cover.new[which(graph_500_psi3_1_u$N==3)]),
  
  c(1,1,2500,-0.3,
    graph_2500_psi1_1_u$bias[which(graph_2500_psi1_1_u$N==1)],
    graph_2500_psi1_1_u$bias[which(graph_2500_psi1_1_u$N==2)],
    graph_2500_psi1_1_u$bias[which(graph_2500_psi1_1_u$N==3)],
    graph_2500_psi1_1_u$cover.old[which(graph_2500_psi1_1_u$N==1)],
    graph_2500_psi1_1_u$cover.old[which(graph_2500_psi1_1_u$N==2)],
    graph_2500_psi1_1_u$cover.old[which(graph_2500_psi1_1_u$N==3)],
    graph_2500_psi1_1_u$cover.new[which(graph_2500_psi1_1_u$N==1)],
    graph_2500_psi1_1_u$cover.new[which(graph_2500_psi1_1_u$N==2)],
    graph_2500_psi1_1_u$cover.new[which(graph_2500_psi1_1_u$N==3)]),
  c(1,1,2500, 0,
    graph_2500_psi2_1_u$bias[which(graph_2500_psi2_1_u$N==1)],
    graph_2500_psi2_1_u$bias[which(graph_2500_psi2_1_u$N==2)],
    graph_2500_psi2_1_u$bias[which(graph_2500_psi2_1_u$N==3)],
    graph_2500_psi2_1_u$cover.old[which(graph_2500_psi2_1_u$N==1)],
    graph_2500_psi2_1_u$cover.old[which(graph_2500_psi2_1_u$N==2)],
    graph_2500_psi2_1_u$cover.old[which(graph_2500_psi2_1_u$N==3)],
    graph_2500_psi2_1_u$cover.new[which(graph_2500_psi2_1_u$N==1)],
    graph_2500_psi2_1_u$cover.new[which(graph_2500_psi2_1_u$N==2)],
    graph_2500_psi2_1_u$cover.new[which(graph_2500_psi2_1_u$N==3)]),
  c(1,1,2500,0.3,
    graph_2500_psi3_1_u$bias[which(graph_2500_psi3_1_u$N==1)],
    graph_2500_psi3_1_u$bias[which(graph_2500_psi3_1_u$N==2)],
    graph_2500_psi3_1_u$bias[which(graph_2500_psi3_1_u$N==3)],
    graph_2500_psi3_1_u$cover.old[which(graph_2500_psi3_1_u$N==1)],
    graph_2500_psi3_1_u$cover.old[which(graph_2500_psi3_1_u$N==2)],
    graph_2500_psi3_1_u$cover.old[which(graph_2500_psi3_1_u$N==3)],
    graph_2500_psi3_1_u$cover.new[which(graph_2500_psi3_1_u$N==1)],
    graph_2500_psi3_1_u$cover.new[which(graph_2500_psi3_1_u$N==2)],
    graph_2500_psi3_1_u$cover.new[which(graph_2500_psi3_1_u$N==3)]),
  
  c(1,1,10000,-0.3,
    graph_10000_psi1_1_u$bias[which(graph_10000_psi1_1_u$N==1)],
    graph_10000_psi1_1_u$bias[which(graph_10000_psi1_1_u$N==2)],
    graph_10000_psi1_1_u$bias[which(graph_10000_psi1_1_u$N==3)],
    graph_10000_psi1_1_u$cover.old[which(graph_10000_psi1_1_u$N==1)],
    graph_10000_psi1_1_u$cover.old[which(graph_10000_psi1_1_u$N==2)],
    graph_10000_psi1_1_u$cover.old[which(graph_10000_psi1_1_u$N==3)],
    graph_10000_psi1_1_u$cover.new[which(graph_10000_psi1_1_u$N==1)],
    graph_10000_psi1_1_u$cover.new[which(graph_10000_psi1_1_u$N==2)],
    graph_10000_psi1_1_u$cover.new[which(graph_10000_psi1_1_u$N==3)]),
  c(1,1,10000, 0,
    graph_10000_psi2_1_u$bias[which(graph_10000_psi2_1_u$N==1)],
    graph_10000_psi2_1_u$bias[which(graph_10000_psi2_1_u$N==2)],
    graph_10000_psi2_1_u$bias[which(graph_10000_psi2_1_u$N==3)],
    graph_10000_psi2_1_u$cover.old[which(graph_10000_psi2_1_u$N==1)],
    graph_10000_psi2_1_u$cover.old[which(graph_10000_psi2_1_u$N==2)],
    graph_10000_psi2_1_u$cover.old[which(graph_10000_psi2_1_u$N==3)],
    graph_10000_psi2_1_u$cover.new[which(graph_10000_psi2_1_u$N==1)],
    graph_10000_psi2_1_u$cover.new[which(graph_10000_psi2_1_u$N==2)],
    graph_10000_psi2_1_u$cover.new[which(graph_10000_psi2_1_u$N==3)]),
  c(1,1,10000,0.3,
    graph_10000_psi3_1_u$bias[which(graph_10000_psi3_1_u$N==1)],
    graph_10000_psi3_1_u$bias[which(graph_10000_psi3_1_u$N==2)],
    graph_10000_psi3_1_u$bias[which(graph_10000_psi3_1_u$N==3)],
    graph_10000_psi3_1_u$cover.old[which(graph_10000_psi3_1_u$N==1)],
    graph_10000_psi3_1_u$cover.old[which(graph_10000_psi3_1_u$N==2)],
    graph_10000_psi3_1_u$cover.old[which(graph_10000_psi3_1_u$N==3)],
    graph_10000_psi3_1_u$cover.new[which(graph_10000_psi3_1_u$N==1)],
    graph_10000_psi3_1_u$cover.new[which(graph_10000_psi3_1_u$N==2)],
    graph_10000_psi3_1_u$cover.new[which(graph_10000_psi3_1_u$N==3)])
  )
table_out<-as.data.frame(table)
colnames(table_out)<-c("Unmeasured Confounding","Treatment Initiation", "Sample Size", "beta","bias1","bias5","bias20","cover.rob1","cover.rob5","cover.rob20","cover.cons1","cover.cons5","cover.cons20")

#print table for latex use
xtable(table_out,digits=c(0,0,0,0,2,3,3,3,3,3,3,3,3,3))

