#################################################################################################
#                                                                                               #
##PROJECT: Robust versus consistent variance estimators in marginal					                    #
#		    	 structural Cox models									                                              #
#                                                                                               #
##PROGRAM NAME: ana_msm.r          	                                                            #
#                                                                                               #
##AUTHOR:       D. Enders					                                     	                        #
#                                                                                               #
##VERSION/DATE: V 1.0 / Nov 13th 2017   				 								                                #
#                                                                                               #
##PURPOSE:      Function to conduct analyses of Cox MSM for treatment-initiation scenario       #
################################################################################################

#########################
#Options  and Packages  #
#########################

memory.limit(size=8000000)
library(PermAlgo)
library(survival)
library(geepack)
library(boot)
library(ipw)
library(Matrix)
library(simex)
library(turner)
library(plyr)
library(lgcp)

################
#Functions     #
################

#Sum of column entries
colsum<-function(x){
  if (is.vector(x))
  {x
  }
  else as.vector(colSums(as.data.frame(x)))
}

#Vector product
vecprod<-function(x,y){
  x%*%t(y)
}

#Elementwise multiplication
mult<-function(x,y){
  x*y
}

#Lagpad - internal function of lag_e
lagpad <- function(x, k) {
  if (!is.vector(x))
    stop('x must be a vector')
  if (!is.numeric(x))
    stop('x must be numeric')
  if (!is.numeric(k))
    stop('k must be numeric')
  if (1 != length(k))
    stop('k must be a single number')
  c(rep(NA, k), x)[1 : length(x)]
}

#Lag_e - replaces vector with column name A of dataset X by a lagged version of A
lag_e<-function(x){
  y<-lagpad(x$A,1)
  y[is.na(y)]=0
  return(y)
}

#msm.ana - conducts MSM analysis
msm.ana2<-function(dat,
                  ID,
                  cens,
                  C,
                  stab,
                  form.denom,
                  form.num,
                  form.denom.cens,
                  form.num.cens,
                  list.denom,
                  list.num,
                  list.denom.cens,
                  list.num.cens,
                  bootind=0,
                  num_boot=1000,
                  marker
                  )
##################################################################################
# dat - input data set                                                           #
# ID - Idnum variable                                                            #
# cens - Indicates if censoring should be accounted for                          #
# C- Indicator of censoring                                                      #
# stab - indicator for use of stabilized or non-stabilized weights               #
# form.denom - formula of denominator in calculation of the IPTW                 #
# form.num - formula of numerator in calculation of the IPTW                     #
# form.denom.cens - formula of denominator in calculation of the IPCW            #
# form.num.cens - formula of numerator in calculation of the IPCW                #
# list.denom - list of variables in denominator in calculation of the IPTW       #
# list.num - list of variables in numerator in calculation of the IPTW           #
# list.denom.cens - list of variables in denominator in calculation of the IPCW  #
# list.num.cens - list of variables in numerator in calculation of the IPCW      #
# marker -  indicates number of visits since initiation                          #
##################################################################################
{
  ###store copies of input data with and without censored observation
  dat_c<-dat
  if (cens==1)
  {
    dat_woc<-dat_c[which(dat_c$C==0),] #This is the final analysis dataset, since censored observations are deleted
  }
  else
  {
    dat_woc<-dat_c
  }
  
  ###data until treatment initiation (marker<2) - needed for weight calculation 
  dat_woc_m<-dat_woc[which(dat_woc$marker<2),]

  ###transforms input formulas so that glm can read them
  formula.denom<-as.formula(form.denom)
  if (stab==1)
  {
     formula.num<-as.formula(form.num)
  }
  if (cens==1)
  {
    formula.denom.cens<-as.formula(form.denom.cens)
    if (stab==1)
    {
      formula.num.cens<-as.formula(form.num.cens)
    }
  }
  
  ###perform regression for numerator and denominator of IPT-weights
  if (stab==1)
  {
    num<-glm(formula.num, data=dat_woc_m, family="binomial")
  }
  denom<-glm(formula.denom, data=dat_woc_m, family="binomial")
  
  ###store vectors of probabilities of receiving treatment for denominator of IPT-weights
  dat_woc$p.denom<-vector("numeric", nrow(dat_woc))
  dat_woc$p.denom[dat_woc$A==0 ]<-1-denom$fitted.values[dat_woc_m$A==0]
  dat_woc$p.denom[dat_woc$A==1 & dat_woc$marker<2]<-denom$fitted.values[dat_woc_m$A==1]
  ###in case treatment is already initialized, weight is set to 1
  dat_woc$p.denom[dat_woc$A==1 & dat_woc$marker>1]<-1
  
  ###Same for numerator of IPT-weights in case of stabilized weights
  if (stab==1)
  {
  dat_woc$p.num<-vector("numeric", nrow(dat_woc))
  dat_woc$p.num[dat_woc$A==0]<-1-num$fitted.values[dat_woc_m$A==0]
  dat_woc$p.num[dat_woc$A==1 & dat_woc$marker<2]<-num$fitted.values[dat_woc_m$A==1]
  dat_woc$p.num[dat_woc$A==1 & dat_woc$marker>1]<-1
  }
  ###Same for the IPC-weights, but estimation with full data dat_c
  if (cens==1)
  {
    if (stab==1)
    {
      num.cens<-glm(formula.num.cens, data=dat_c, family="binomial")
    }
    denom.cens<-glm(formula.denom.cens, data=dat_c, family="binomial")
    dat_woc$p.denom.cens<-vector("numeric", nrow(dat_woc))
    dat_woc$p.denom.cens<-1-denom.cens$fitted.values[dat_c$C==0]
    if (stab==1)
    {
    dat_woc$p.num.cens<-vector("numeric", nrow(dat_woc))
    dat_woc$p.num.cens<-1-num.cens$fitted.values[dat_c$C==0]
    }
  }
  
  if (cens==1)
  {
    #calculate product of IPT-weights and IPC-weights
    if (stab==1)
    {
      dat_woc$p<-dat_woc$p.num*dat_woc$p.num.cens/(dat_woc$p.denom*dat_woc$p.denom.cens)
    }
    else
    {
      dat_woc$p<-1/(dat_woc$p.denom*dat_woc$p.denom.cens)
    }
  }
  else
  {
    #calculate IPT-weights only
    if (stab==1)
    {
      dat_woc$p<-dat_woc$p.num/(dat_woc$p.denom)
    }
    else
    {
      dat_woc$p<-1/(dat_woc$p.denom)
    }
  }
  ###calculate cumulative product of IPT-weights (or IPT-weight*IPC-weight) over all observations of each individual,
  ###i.e. over all treatment visits
  dat_woc$ipw2<-unlist(lapply(split(with(dat_woc,p), dat_woc$Id), function(x) cumprod(x)))
  ###calculate IPTW or IPTW*IPTC weighted analysis
  gee<-geeglm(Y~A, data=dat_woc, id=dat_woc$Id, family="binomial", corstr="independence", weights=ipw2)
  
  ###store prediction of the MSM for each individual
  eta<-as.vector(cbind(1,dat_woc$A)%*%(as.vector(gee$coefficients)))
  DELTA<-Diagonal(length(eta),1)

  ###calculation of H_bb^(-1), the ^(-1) is left from the name due to convenience
  ###H_bb was crosschecked by the results from the gee procedure
  A<-Diagonal(length(eta),exp(eta)/(1+exp(eta))^2)
  W<-Diagonal(length(eta),dat_woc$ipw2)
  V<-sqrt(A)%*%solve(W)%*%sqrt(A)
  X<-cbind(1,dat_woc$A)
  D<-A%*%DELTA%*%X
  H_bb<-gee$geese$vbeta.naiv

  ### calculation of F_b
  ### F_b was crosschecked by the results from the gee procedure
  cnt<-count(dat_woc,vars="Id")$freq
  S<-dat_woc$Y-exp(eta)/(1+exp(eta))
  block1<-matrix_to_blocks(as.matrix(D),blocks=cnt)
  block2<-matrix_to_blocks(as.matrix(solve(V)%*%S),block=cnt)
  block3<-mapply(mult,block1,block2, SIMPLIFY=FALSE)
  block4<-lapply(block3,colsum)
  block5<-mapply(vecprod,block4,block4, SIMPLIFY = FALSE)
  F_b<-Reduce('+',block5)

  ###Validation of calculation with the robust variance estimator of gee procedure
  #print(H_bb%*%F_b%*%H_bb)
  #print(gee$geese$vbeta)
  
  ###calculation of F_a_num^(-1), F_a_denom^(-1), F_a_num.cens^(-1) and F_a_denom.cens^(-1)
  ###subscripts and ^(-1) again left from the variable name for convenience
  ###these are observed information matrix from the corresponding pooled logistic regression
  if (stab==1)
    {
    F_num<-vcov(num)
    }

  F_denom<-vcov(denom)
  if (cens==1)
  {
    if (stab==1)
    {
      F_num.cens<-vcov(num.cens)
    }
    F_denom.cens<-vcov(denom.cens)
  }
  ###calculation of H_ba_num^(-1), H_ba_denom^(-1), H_ba_num.cens^(-1) and H_ba_denom.cens^(-1)
  ###subscripts and ^(-1) again left from the variable name for convenience
  ###Calculation are analogous to H_bb(-1) above, but with two different score vectors
  ###See also formulas in article for reference.
  
  ###block4_denom are the individual score contributions u_alpha(alpha^(a))
  ###block3_denom are the score contributions from each patient visits

  eta_denom<-as.vector(cbind(1,as.matrix(dat_woc_m[,list.denom]))%*%(as.vector(denom$coefficients)))
  DELTA_denom<-Diagonal(nrow(dat_woc),1)
  X_denom<-cbind(1,as.matrix(dat_woc[,list.denom]))
  S_denom<-vector("numeric", nrow(dat_woc))
  S_denom[which(dat_woc$marker<2)]<-dat_woc_m$A-exp(eta_denom)/(1+exp(eta_denom))
  ###Visits after treatment initiation are by definition assigned a weight of 1, the derivative with
  ###respect to alpha is thus zero -> no contributions to the score
  S_denom[which(dat_woc$marker>1)]<-0
  block1_denom<-matrix_to_blocks(as.matrix(X_denom),blocks=cnt)
  block2_denom<-matrix_to_blocks(as.matrix(DELTA_denom%*%S_denom),block=cnt)
  block3_denom<-mapply(mult,block1_denom,block2_denom, SIMPLIFY=FALSE)
  block4_denom<-lapply(block3_denom,colsum)
  block5_denom<-mapply(vecprod,block4,block4_denom, SIMPLIFY = FALSE)
  H_denom<-Reduce('+',block5_denom)

  if (stab==1)
  {
    ###analogous calculations as for the denominator
    if (list.num[1]=="INTERCEPT")
    {
      eta_num<-as.vector(rep(num$coefficients,nrow(dat_woc_m)))
      X_num<-as.matrix(rep(1,nrow(dat_woc)),ncol=1)
    }
    else
    {
      eta_num<-as.vector(cbind(1,as.matrix(dat_woc_m[,list.num]))%*%(as.vector(num$coefficients)))
      X_num<-cbind(1,as.matrix(dat_woc[,list.num]))
    }
    DELTA_num<-Diagonal(nrow(dat_woc),1)
    S_num<-vector("numeric", nrow(dat_woc))
    S_num[which(dat_woc$marker<2)]<-dat_woc_m$A-exp(eta_num)/(1+exp(eta_num))
    S_num[which(dat_woc$marker>1)]<-0
    block1_num<-matrix_to_blocks(as.matrix(X_num),blocks=cnt)
    block2_num<-matrix_to_blocks(as.matrix(DELTA_num%*%S_num),block=cnt)
    block3_num<-mapply(mult,block1_num,block2_num, SIMPLIFY=FALSE)
    if (list.num[1]=="INTERCEPT")
    {
      block4_num<-lapply(block3_num,sum)
    }
    else
    {
      block4_num<-lapply(block3_num,colsum)
    }
    block5_num<-mapply(vecprod,block4,block4_num, SIMPLIFY = FALSE)
    H_num<-Reduce('+',block5_num)
  }
  if (cens==1)
  { ###Patients with censoring in the first visit do not contribute to the score u_w(beta,alpha)
    ###They are thus not relevant for H_denom_cens^(-1)
    ###They need to be removed from this calculation for proper matrix multiplications
    ###else proceed as for H_denom
    dat_c2<-dat_c[-which(dat_c$tp==1 &dat_c$C==1),]
    cnt_c<-count(dat_c2,vars="Id")$freq
    eta_denom.cens<-as.vector(cbind(1,as.matrix(dat_c2[,list.denom.cens]))%*%(as.vector(denom.cens$coefficients)))
    DELTA_denom.cens<-Diagonal(length(eta_denom.cens),1)
    X_denom.cens<-cbind(1,as.matrix(dat_c2[,list.denom.cens]))
    S_denom.cens<-dat_c2$C-exp(eta_denom.cens)/(1+exp(eta_denom.cens))
    block1_denom.cens<-matrix_to_blocks(as.matrix(X_denom.cens),blocks=cnt_c)
    block2_denom.cens<-matrix_to_blocks(as.matrix(DELTA_denom.cens%*%S_denom.cens),block=cnt_c)
    block3_denom.cens<-mapply(mult,block1_denom.cens,block2_denom.cens, SIMPLIFY=FALSE)
    block4_denom.cens<-lapply(block3_denom.cens,colsum)
    block5_denom.cens<-mapply(vecprod,block4,block4_denom.cens, SIMPLIFY = FALSE)
    H_denom.cens<-Reduce('+',block5_denom.cens)

    if (stab==1)
    {
      eta_num.cens<-as.vector(cbind(1,as.matrix(dat_woc[,list.num.cens]))%*%(as.vector(num.cens$coefficients)))
      DELTA_num.cens<-Diagonal(length(eta_num.cens),1)
      X_num.cens<-cbind(1,as.matrix(dat_woc[,list.num.cens]))
      S_num.cens<-dat_woc$Y-exp(eta_num.cens)/(1+exp(eta_num.cens))
      block1_num.cens<-matrix_to_blocks(as.matrix(X_num.cens),blocks=cnt)
      block2_num.cens<-matrix_to_blocks(as.matrix(DELTA_num.cens%*%S_num.cens),block=cnt)
      block3_num.cens<-mapply(mult,block1_num.cens,block2_num.cens, SIMPLIFY=FALSE)
      block4_num.cens<-lapply(block3_num.cens,colsum)
      block5_num.cens<-mapply(vecprod,block4,block4_num.cens, SIMPLIFY = FALSE)
      H_num.cens<-Reduce('+',block5_num.cens)
    }
  }

  ###Calculate variance formula according to formulas in manuscript
  if (cens==1)
  {
    if (stab==1)
    {
    var_w_est<-H_bb%*%(F_b-H_denom%*%F_denom%*%t(H_denom)-H_num%*%F_num%*%t(H_num)-H_denom.cens%*%F_denom.cens%*%t(H_denom.cens)-H_num.cens%*%F_num.cens%*%t(H_num.cens))%*%H_bb
    }
    else
    {
      var_w_est<-H_bb%*%(F_b-H_denom%*%F_denom%*%t(H_denom)-H_denom.cens%*%F_denom.cens%*%t(H_denom.cens))%*%H_bb
    }
  }
  else
  {
    if (stab==1)
    {
    var_w_est<-H_bb%*%(F_b-H_denom%*%F_denom%*%t(H_denom)-H_num%*%F_num%*%t(H_num))%*%H_bb
    }
    else
    {
    var_w_est<-H_bb%*%(F_b-H_denom%*%F_denom%*%t(H_denom))%*%H_bb
    }
  }

  ###out contains the estimated coefficients and all variance estimates, i.e. classic and adapted
  out<-c(gee$coefficients[2],gee$geese$vbeta[2,2],var_w_est[2,2])
  return(out)
}

